==> open-xchange-core_7.6.0.orig.tar.bz2: open-xchange-core-7.6.0/javax.mail/src/com/sun/mail/imap/protocol/FetchItem.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2013 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.mail.imap.protocol;

import java.lang.reflect.*;

import javax.mail.FetchProfile;
import com.sun.mail.iap.ParsingException;

/**
 * Metadata describing a FETCH item.
 * Note that the "name" field MUST be in uppercase. <p>
 *
 * @author  Bill Shannon
 * @since JavaMail 1.4.6
 */

public abstract class FetchItem { 
    private String name;
    private FetchProfile.Item fetchProfileItem;

    public FetchItem(String name, FetchProfile.Item fetchProfileItem) {
	this.name = name;
	this.fetchProfileItem = fetchProfileItem;
    }

    public String getName() {
	return name;
    }

    public FetchProfile.Item getFetchProfileItem() {
	return fetchProfileItem;
    }

    /**
     * Parse the item into some kind of object appropriate for the item.
     * Note that the item name will have been parsed and skipped already.
     */
    public abstract Object parseItem(FetchResponse r) throws ParsingException;
}

==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/javax.mail/src/com/sun/mail/imap/protocol/FetchItem.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 1997-2018 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://oss.oracle.com/licenses/CDDL+GPL-1.1
 * or LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.mail.imap.protocol;

import javax.mail.FetchProfile;
import com.sun.mail.iap.ParsingException;

/**
 * Metadata describing a FETCH item.
 * Note that the "name" field MUST be in uppercase. <p>
 *
 * @author  Bill Shannon
 * @since JavaMail 1.4.6
 */

public abstract class FetchItem { 
    private String name;
    private FetchProfile.Item fetchProfileItem;

    public FetchItem(String name, FetchProfile.Item fetchProfileItem) {
	this.name = name;
	this.fetchProfileItem = fetchProfileItem;
    }

    public String getName() {
	return name;
    }

    public FetchProfile.Item getFetchProfileItem() {
	return fetchProfileItem;
    }

    /**
     * Parse the item into some kind of object appropriate for the item.
     * Note that the item name will have been parsed and skipped already.
     *
     * @param	r	the response
     * @return		the fetch item
     * @exception	ParsingException	for parsing failures
     */
    public abstract Object parseItem(FetchResponse r) throws ParsingException;
}
